@@ -32,16 +32,12 @@ THE SOFTWARE.
 #include "OgrePrerequisites.h"
 
 #include "OgreSingleton.h"
-#include "OgreHardwareCounterBuffer.h"
 #include "OgreHardwareIndexBuffer.h"
-#include "OgreHardwareUniformBuffer.h"
 #include "OgreHardwareVertexBuffer.h"
-#include "OgreHlmsManager.h" //For OGRE_HLMS_NUM_INPUT_LAYOUTS
 #include "Threading/OgreThreadHeaders.h"
 #include "OgreHeaderPrefix.h"
 
 namespace Ogre {
-namespace v1 {
     /** \addtogroup Core
     *  @{
     */
@@ -50,7 +46,7 @@ namespace v1 {
     */
 
     /** Abstract interface representing a 'licensee' of a hardware buffer copy.
-    @remarks
+
         Often it's useful to have temporary buffers which are used for working
         but are not necessarily needed permanently. However, creating and 
         destroying buffers is expensive, so we need a way to share these 
@@ -79,10 +75,11 @@ namespace v1 {
         // Post-blended 
         HardwareVertexBufferSharedPtr destPositionBuffer;
         HardwareVertexBufferSharedPtr destNormalBuffer;
-        /// Both positions and normals are contained in the same buffer.
-        bool posNormalShareBuffer;
         unsigned short posBindIndex;
         unsigned short normBindIndex;
+        /// Both positions and normals are contained in the same buffer.
+        bool posNormalShareBuffer;
+        bool posNormalExtraData;
         bool bindPositions;
         bool bindNormals;
 
@@ -102,52 +99,38 @@ namespace v1 {
 
 
     /** Base definition of a hardware buffer manager.
-    @remarks
+
         This class is deliberately not a Singleton, so that multiple types can 
-        exist at once. The Singleton is wrapped via the Decorator pattern
-        in HardwareBufferManager, below. Each concrete implementation should
-        provide a subclass of HardwareBufferManagerBase, which does the actual
-        work, and also a very simple subclass of HardwareBufferManager which 
-        simply constructs the instance of the HardwareBufferManagerBase subclass 
-        and passes it to the HardwareBufferManager superclass as a delegate. 
-        This subclass must also delete the implementation instance it creates.
+        exist at once (notably DefaultHardwareBufferManagerBase).
+        The Singleton is add via the inheritance in HardwareBufferManager below.
     */
     class _OgreExport HardwareBufferManagerBase : public BufferAlloc
     {
-        friend class HardwareVertexBufferSharedPtr;
-        friend class HardwareIndexBufferSharedPtr;
     protected:
-        /** WARNING: The following two members should place before all other members.
+        /** WARNING: The following member should place before all other members.
             Members destruct order is very important here, because destructing other
             members will cause notify back to this class, and then will access to this
             two members.
         */
-        typedef set<HardwareVertexBuffer*>::type VertexBufferList;
-        typedef set<HardwareIndexBuffer*>::type IndexBufferList;
-        typedef set<HardwareUniformBuffer*>::type UniformBufferList;
-        typedef set<HardwareCounterBuffer*>::type CounterBufferList;
+        typedef std::set<HardwareVertexBuffer*> VertexBufferList;
+        typedef std::set<HardwareIndexBuffer*> IndexBufferList;
         VertexBufferList mVertexBuffers;
-        IndexBufferList mIndexBuffers;
-        UniformBufferList mUniformBuffers;
-        CounterBufferList mCounterBuffers;
 
-        typedef set<VertexDeclaration*>::type VertexDeclarationList;
-        typedef set<VertexBufferBinding*>::type VertexBufferBindingList;
+
+        typedef std::set<VertexDeclaration*> VertexDeclarationList;
+        typedef std::set<VertexBufferBinding*> VertexBufferBindingList;
         VertexDeclarationList mVertexDeclarations;
         VertexBufferBindingList mVertexBufferBindings;
 
         // Mutexes
         OGRE_MUTEX(mVertexBuffersMutex);
-        OGRE_MUTEX(mIndexBuffersMutex);
-        OGRE_MUTEX(mUniformBuffersMutex);
-        OGRE_MUTEX(mCounterBuffersMutex);
         OGRE_MUTEX(mVertexDeclarationsMutex);
         OGRE_MUTEX(mVertexBufferBindingsMutex);
 
         /// Internal method for destroys all vertex declarations.
-        virtual void destroyAllDeclarations(void);
+        void destroyAllDeclarations(void);
         /// Internal method for destroys all vertex buffer bindings.
-        virtual void destroyAllBindings(void);
+        void destroyAllBindings(void);
 
         /// Internal method for creates a new vertex declaration, may be overridden by certain rendering APIs.
         virtual VertexDeclaration* createVertexDeclarationImpl(void);
@@ -169,7 +152,7 @@ namespace v1 {
             BLT_AUTOMATIC_RELEASE
         };
 
-    protected:
+    private:
         /** Struct holding details of a license to use a temporary shared buffer. */
         class _OgrePrivate VertexBufferLicense
         {
@@ -195,11 +178,11 @@ namespace v1 {
         };
 
         /// Map from original buffer to temporary buffers.
-        typedef multimap<HardwareVertexBuffer*, HardwareVertexBufferSharedPtr>::type FreeTemporaryVertexBufferMap;
+        typedef std::multimap<HardwareVertexBuffer*, HardwareVertexBufferSharedPtr> FreeTemporaryVertexBufferMap;
         /// Map of current available temp buffers.
         FreeTemporaryVertexBufferMap mFreeTempVertexBufferMap;
         /// Map from temporary buffer to details of a license.
-        typedef map<HardwareVertexBuffer*, VertexBufferLicense>::type TemporaryVertexBufferLicenseMap;
+        typedef std::map<HardwareVertexBuffer*, VertexBufferLicense> TemporaryVertexBufferLicenseMap;
         /// Map of currently licensed temporary buffers.
         TemporaryVertexBufferLicenseMap mTempVertexBufferLicenses;
         /// Number of frames elapsed since temporary buffers utilization was above half the available.
@@ -221,7 +204,7 @@ namespace v1 {
         HardwareBufferManagerBase();
         virtual ~HardwareBufferManagerBase();
         /** Create a hardware vertex buffer.
-        @remarks
+
             This method creates a new vertex buffer; this will act as a source of geometry
             data for rendering objects. Note that because the meaning of the contents of
             the vertex buffer depends on the usage, this method does not specify a
@@ -231,8 +214,8 @@ namespace v1 {
             of the rendering pipeline, e.g. a position, or texture coordinates. This is done 
             using the VertexDeclaration class, which itself contains VertexElement structures
             referring to the source data.
-        @remarks Note that because vertex buffers can be shared, they are reference
-            counted so you do not need to worry about destroying themm this will be done
+            Note that because vertex buffers can be shared, they are reference
+            counted so you do not need to worry about destroying them this will be done
             automatically.
         @param vertexSize
             The size in bytes of each vertex in this buffer; you must calculate
@@ -240,17 +223,12 @@ namespace v1 {
         @param numVerts
             The number of vertices in this buffer.
         @param usage
-            One or more members of the HardwareBuffer::Usage enumeration; you are
-            strongly advised to use HBU_STATIC_WRITE_ONLY wherever possible, if you need to 
-            update regularly, consider HBU_DYNAMIC_WRITE_ONLY and useShadowBuffer=true.
+            One or more members of the #HardwareBufferUsage enumeration; you are
+            strongly advised to use #HBU_GPU_ONLY wherever possible, if you need to
+            update regularly, consider #HBU_CPU_TO_GPU or useShadowBuffer=true.
         @param useShadowBuffer
             If set to @c true, this buffer will be 'shadowed' by one stored in 
-            system memory rather than GPU or AGP memory. You should set this flag if you intend 
-            to read data back from the vertex buffer, because reading data from a buffer
-            in the GPU or AGP memory is very expensive, and is in fact impossible if you
-            specify HBU_WRITE_ONLY for the main buffer. If you use this option, all 
-            reads and writes will be done to the shadow buffer, and the shadow buffer will
-            be synchronised with the real buffer at an appropriate time.
+            system memory rather than GPU memory. See @ref Shadow-Buffers.
         */
         virtual HardwareVertexBufferSharedPtr 
             createVertexBuffer(size_t vertexSize, size_t numVerts, HardwareBuffer::Usage usage, 
@@ -265,49 +243,42 @@ namespace v1 {
         @param numIndexes
             The number of indexes in the buffer
         @param usage
-            One or more members of the HardwareBuffer::Usage enumeration.
+            One or more members of the #HardwareBufferUsage enumeration.
         @param useShadowBuffer
             If set to @c true, this buffer will be 'shadowed' by one stored in 
-            system memory rather than GPU or AGP memory. You should set this flag if you intend 
-            to read data back from the index buffer, because reading data from a buffer
-            in the GPU or AGP memory is very expensive, and is in fact impossible if you
-            specify HBU_WRITE_ONLY for the main buffer. If you use this option, all 
-            reads and writes will be done to the shadow buffer, and the shadow buffer will
-            be synchronised with the real buffer at an appropriate time.
+            system memory rather than GPU memory. See @ref Shadow-Buffers.
         */
         virtual HardwareIndexBufferSharedPtr 
             createIndexBuffer(HardwareIndexBuffer::IndexType itype, size_t numIndexes, 
             HardwareBuffer::Usage usage, bool useShadowBuffer = false) = 0;
 
+        /** Create a render to vertex buffer.
+        @remarks The parameters (such as vertex size etc) are determined later
+            and are allocated when needed.
+        */
+        virtual RenderToVertexBufferSharedPtr createRenderToVertexBuffer();
+
         /**
          * Create uniform buffer. This type of buffer allows the upload of shader constants once,
          * and sharing between shader stages or even shaders from another materials. 
          * The update shall be triggered by GpuProgramParameters, if is dirty
          */
-        virtual HardwareUniformBufferSharedPtr createUniformBuffer(size_t sizeBytes, 
-                                    HardwareBuffer::Usage usage = HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE, 
-                                    bool useShadowBuffer = false, const String& name = "") = 0;
-
-        /**
-         * Create counter buffer.
-         * The update shall be triggered by GpuProgramParameters, if is dirty
-         */
-        virtual HardwareCounterBufferSharedPtr createCounterBuffer(size_t sizeBytes,
-                                                                   HardwareBuffer::Usage usage = HardwareBuffer::HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE,
-                                                                   bool useShadowBuffer = false, const String& name = "") = 0;
+        virtual HardwareBufferPtr createUniformBuffer(size_t sizeBytes,
+                                                      HardwareBufferUsage usage = HBU_CPU_TO_GPU,
+                                                      bool useShadowBuffer = false);
 
         /** Creates a new vertex declaration. */
-        virtual VertexDeclaration* createVertexDeclaration(void);
+        VertexDeclaration* createVertexDeclaration(void);
         /** Destroys a vertex declaration. */
-        virtual void destroyVertexDeclaration(VertexDeclaration* decl);
+        void destroyVertexDeclaration(VertexDeclaration* decl);
 
         /** Creates a new VertexBufferBinding. */
-        virtual VertexBufferBinding* createVertexBufferBinding(void);
+        VertexBufferBinding* createVertexBufferBinding(void);
         /** Destroys a VertexBufferBinding. */
-        virtual void destroyVertexBufferBinding(VertexBufferBinding* binding);
+        void destroyVertexBufferBinding(VertexBufferBinding* binding);
 
         /** Registers a vertex buffer as a copy of another.
-        @remarks
+
             This is useful for registering an existing buffer as a temporary buffer
             which can be allocated just like a copy.
         */
@@ -316,7 +287,7 @@ namespace v1 {
             const HardwareVertexBufferSharedPtr& copy);
 
         /** Allocates a copy of a given vertex buffer.
-        @remarks
+
             This method allocates a temporary copy of an existing vertex buffer.
             This buffer is subsequently stored and can be made available for 
             other purposes later without incurring the cost of construction / 
@@ -335,14 +306,14 @@ namespace v1 {
             If @c true, the current data is copied as well as the 
             structure of the buffer/
         */
-        virtual HardwareVertexBufferSharedPtr allocateVertexBufferCopy(
+        HardwareVertexBufferSharedPtr allocateVertexBufferCopy(
             const HardwareVertexBufferSharedPtr& sourceBuffer, 
             BufferLicenseType licenseType,
             HardwareBufferLicensee* licensee,
             bool copyData = false);
 
         /** Manually release a vertex buffer copy for others to subsequently use.
-        @remarks
+
             Only required if the original call to allocateVertexBufferCopy
             included a licenseType of BLT_MANUAL_RELEASE. 
         @param bufferCopy
@@ -350,11 +321,10 @@ namespace v1 {
             or at least no longer use this reference, since another user may
             well begin to modify the contents of the buffer.
         */
-        virtual void releaseVertexBufferCopy(
-            const HardwareVertexBufferSharedPtr& bufferCopy); 
+        void releaseVertexBufferCopy(const HardwareVertexBufferSharedPtr& bufferCopy);
 
         /** Tell engine that the vertex buffer copy intent to reuse.
-        @remarks
+
             Ogre internal keep an expired delay counter of BLT_AUTOMATIC_RELEASE
             buffers, when the counter count down to zero, it'll release for other
             purposes later. But you can use this function to reset the counter to
@@ -364,10 +334,10 @@ namespace v1 {
             The buffer copy. The caller is expected to keep this
             buffer copy for use.
         */
-        virtual void touchVertexBufferCopy(const HardwareVertexBufferSharedPtr& bufferCopy);
+        void touchVertexBufferCopy(const HardwareVertexBufferSharedPtr& bufferCopy);
 
         /** Free all unused vertex buffer copies.
-        @remarks
+
             This method free all temporary vertex buffers that not in used.
             In normally, temporary vertex buffers are subsequently stored and can
             be made available for other purposes later without incurring the cost
@@ -375,7 +345,7 @@ namespace v1 {
             to save hardware memory (e.g. application was runs in a long time, you
             might free temporary buffers periodically to avoid memory overload).
         */
-        virtual void _freeUnusedBufferCopies(void);
+        void _freeUnusedBufferCopies(void);
 
         /** Internal method for releasing all temporary buffers which have been 
            allocated using BLT_AUTOMATIC_RELEASE; is called by OGRE.
@@ -384,10 +354,10 @@ namespace v1 {
             If @c false, auto detect and free all unused temporary buffers based on
             temporary buffers utilization.
         */
-        virtual void _releaseBufferCopies(bool forceFreeUnused = false);
+        void _releaseBufferCopies(bool forceFreeUnused = false);
 
         /** Internal method that forces the release of copies of a given buffer.
-        @remarks
+
             This usually means that the buffer which the copies are based on has
             been changed in some fundamental way, and the owner of the original 
             wishes to make that known so that new copies will reflect the
@@ -396,10 +366,10 @@ namespace v1 {
             The source buffer as a shared pointer.  Any buffer copies created
             from the source buffer are deleted.
         */
-        virtual void _forceReleaseBufferCopies(const HardwareVertexBufferSharedPtr& sourceBuffer);
+        void _forceReleaseBufferCopies(const HardwareVertexBufferSharedPtr& sourceBuffer);
 
         /** Internal method that forces the release of copies of a given buffer.
-        @remarks
+
             This usually means that the buffer which the copies are based on has
             been changed in some fundamental way, and the owner of the original 
             wishes to make that known so that new copies will reflect the
@@ -408,190 +378,28 @@ namespace v1 {
             The source buffer as a pointer. Any buffer copies created from
             the source buffer are deleted.
         */
-        virtual void _forceReleaseBufferCopies(HardwareVertexBuffer* sourceBuffer);
+        void _forceReleaseBufferCopies(HardwareVertexBuffer* sourceBuffer);
 
         /// Notification that a hardware vertex buffer has been destroyed.
         void _notifyVertexBufferDestroyed(HardwareVertexBuffer* buf);
-        /// Notification that a hardware index buffer has been destroyed.
-        void _notifyIndexBufferDestroyed(HardwareIndexBuffer* buf);
-        /// Notification that at hardware uniform buffer has been destroyed
-        void _notifyUniformBufferDestroyed(HardwareUniformBuffer* buf);
-        /// Notification that at hardware counter buffer has been destroyed
-        void _notifyCounterBufferDestroyed(HardwareCounterBuffer* buf);
     };
 
     /** Singleton wrapper for hardware buffer manager. */
     class _OgreExport HardwareBufferManager : public HardwareBufferManagerBase, public Singleton<HardwareBufferManager>
     {
-        friend class HardwareVertexBufferSharedPtr;
-        friend class HardwareIndexBufferSharedPtr;
-    protected:
-        HardwareBufferManagerBase* mImpl;
-
     public:
-        HardwareBufferManager(HardwareBufferManagerBase* imp);
+        HardwareBufferManager();
         ~HardwareBufferManager();
 
-        /** @copydoc HardwareBufferManagerBase::createVertexBuffer */
-        HardwareVertexBufferSharedPtr 
-            createVertexBuffer(size_t vertexSize, size_t numVerts, HardwareBuffer::Usage usage, 
-            bool useShadowBuffer = false)
-        {
-            return mImpl->createVertexBuffer(vertexSize, numVerts, usage, useShadowBuffer);
-        }
-        /** @copydoc HardwareBufferManagerBase::createIndexBuffer */
-        HardwareIndexBufferSharedPtr 
-            createIndexBuffer(HardwareIndexBuffer::IndexType itype, size_t numIndexes, 
-            HardwareBuffer::Usage usage, bool useShadowBuffer = false)
-        {
-            return mImpl->createIndexBuffer(itype, numIndexes, usage, useShadowBuffer);
-        }
-
-        /** @copydoc HardwareBufferManagerBase::createUniformBuffer */
-        HardwareUniformBufferSharedPtr
-                createUniformBuffer(size_t sizeBytes, HardwareBuffer::Usage usage, bool useShadowBuffer, const String& name = "")
-        {
-            return mImpl->createUniformBuffer(sizeBytes, usage, useShadowBuffer, name);
-        }
-        
-        /** @copydoc HardwareBufferManagerBase::createCounterBuffer */
-        HardwareCounterBufferSharedPtr
-        createCounterBuffer(size_t sizeBytes, HardwareBuffer::Usage usage, bool useShadowBuffer, const String& name = "")
-        {
-            return mImpl->createCounterBuffer(sizeBytes, usage, useShadowBuffer, name);
-        }
-
-        /** @copydoc HardwareBufferManagerInterface::createVertexDeclaration */
-        virtual VertexDeclaration* createVertexDeclaration(void)
-        {
-            return mImpl->createVertexDeclaration();
-        }
-        /** @copydoc HardwareBufferManagerBase::destroyVertexDeclaration */
-        virtual void destroyVertexDeclaration(VertexDeclaration* decl)
-        {
-            mImpl->destroyVertexDeclaration(decl);
-        }
-
-        /** @copydoc HardwareBufferManagerBase::createVertexBufferBinding */
-        virtual VertexBufferBinding* createVertexBufferBinding(void)
-        {
-            return mImpl->createVertexBufferBinding();
-        }
-        /** @copydoc HardwareBufferManagerBase::destroyVertexBufferBinding */
-        virtual void destroyVertexBufferBinding(VertexBufferBinding* binding)
-        {
-            mImpl->destroyVertexBufferBinding(binding);
-        }
-        /** @copydoc HardwareBufferManagerBase::registerVertexBufferSourceAndCopy */
-        virtual void registerVertexBufferSourceAndCopy(
-            const HardwareVertexBufferSharedPtr& sourceBuffer,
-            const HardwareVertexBufferSharedPtr& copy)
-        {
-            mImpl->registerVertexBufferSourceAndCopy(sourceBuffer, copy);
-        }
-        /** @copydoc HardwareBufferManagerBase::allocateVertexBufferCopy */
-        virtual HardwareVertexBufferSharedPtr allocateVertexBufferCopy(
-            const HardwareVertexBufferSharedPtr& sourceBuffer, 
-            BufferLicenseType licenseType,
-            HardwareBufferLicensee* licensee,
-            bool copyData = false)
-        {
-            return mImpl->allocateVertexBufferCopy(sourceBuffer, licenseType, licensee, copyData);
-        }
-        /** @copydoc HardwareBufferManagerBase::releaseVertexBufferCopy */
-        virtual void releaseVertexBufferCopy(
-            const HardwareVertexBufferSharedPtr& bufferCopy)
-        {
-            mImpl->releaseVertexBufferCopy(bufferCopy);
-        }
-
-        /** @copydoc HardwareBufferManagerBase::touchVertexBufferCopy */
-        virtual void touchVertexBufferCopy(
-            const HardwareVertexBufferSharedPtr& bufferCopy)
-        {
-            mImpl->touchVertexBufferCopy(bufferCopy);
-        }
-
-        /** @copydoc HardwareBufferManagerBase::_freeUnusedBufferCopies */
-        virtual void _freeUnusedBufferCopies(void)
-        {
-            mImpl->_freeUnusedBufferCopies();
-        }
-        /** @copydoc HardwareBufferManagerBase::_releaseBufferCopies */
-        virtual void _releaseBufferCopies(bool forceFreeUnused = false)
-        {
-            mImpl->_releaseBufferCopies(forceFreeUnused);
-        }
-        /** @copydoc HardwareBufferManagerBase::_forceReleaseBufferCopies */
-        virtual void _forceReleaseBufferCopies(
-            const HardwareVertexBufferSharedPtr& sourceBuffer)
-        {
-            mImpl->_forceReleaseBufferCopies(sourceBuffer);
-        }
-        /** @copydoc HardwareBufferManagerBase::_forceReleaseBufferCopies */
-        virtual void _forceReleaseBufferCopies(HardwareVertexBuffer* sourceBuffer)
-        {
-            mImpl->_forceReleaseBufferCopies(sourceBuffer);
-        }
-        /** @copydoc HardwareBufferManagerBase::_notifyVertexBufferDestroyed */
-        void _notifyVertexBufferDestroyed(HardwareVertexBuffer* buf)
-        {
-            mImpl->_notifyVertexBufferDestroyed(buf);
-        }
-        /** @copydoc HardwareBufferManagerBase::_notifyIndexBufferDestroyed */
-        void _notifyIndexBufferDestroyed(HardwareIndexBuffer* buf)
-        {
-            mImpl->_notifyIndexBufferDestroyed(buf);
-        }
-        /** @copydoc HardwareBufferManagerInterface::_notifyUniformBufferDestroyed */
-        void _notifyUniformBufferDestroyed(HardwareUniformBuffer* buf)
-        {
-            mImpl->_notifyUniformBufferDestroyed(buf);
-        }
-        /** @copydoc HardwareBufferManagerInterface::_notifyCounterBufferDestroyed */
-        void _notifyConterBufferDestroyed(HardwareCounterBuffer* buf)
-        {
-            mImpl->_notifyCounterBufferDestroyed(buf);
-        }
-
-        /** Override standard Singleton retrieval.
-        @remarks
-        Why do we do this? Well, it's because the Singleton
-        implementation is in a .h file, which means it gets compiled
-        into anybody who includes it. This is needed for the
-        Singleton template to work, but we actually only want it
-        compiled into the implementation of the class based on the
-        Singleton, not all of them. If we don't change this, we get
-        link errors when trying to use the Singleton-based class from
-        an outside dll.
-        @par
-        This method just delegates to the template version anyway,
-        but the implementation stays in this single compilation unit,
-        preventing link errors.
-        */
+        /// @copydoc Singleton::getSingleton()
         static HardwareBufferManager& getSingleton(void);
-        /** Override standard Singleton retrieval.
-        @remarks
-        Why do we do this? Well, it's because the Singleton
-        implementation is in a .h file, which means it gets compiled
-        into anybody who includes it. This is needed for the
-        Singleton template to work, but we actually only want it
-        compiled into the implementation of the class based on the
-        Singleton, not all of them. If we don't change this, we get
-        link errors when trying to use the Singleton-based class from
-        an outside dll.
-        @par
-        This method just delegates to the template version anyway,
-        but the implementation stays in this single compilation unit,
-        preventing link errors.
-        */
+        /// @copydoc Singleton::getSingleton()
         static HardwareBufferManager* getSingletonPtr(void);
 
     };
 
     /** @} */
     /** @} */
-}
 } // namespace Ogre
 
 #include "OgreHeaderSuffix.h"
