@@ -5,5 +5,6 @@ var class_ogre_1_1_d3_d9_render_texture =
     [ "update", "class_ogre_1_1_d3_d9_render_texture.html#a32cf8d57216718b77712692526a3949a", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d9_render_texture.html#ac2e9d5aee6ba97ecfdddd6080893fdf9", null ],
     [ "requiresTextureFlipping", "class_ogre_1_1_d3_d9_render_texture.html#a5c13d919d5cdc70953e07f61d72d4f2c", null ],
-    [ "swapBuffers", "class_ogre_1_1_d3_d9_render_texture.html#aec4dff6a7bf928559f79579a8ccc1682", null ]
+    [ "swapBuffers", "class_ogre_1_1_d3_d9_render_texture.html#aec4dff6a7bf928559f79579a8ccc1682", null ],
+    [ "_setDepthBuffer", "class_ogre_1_1_d3_d9_render_texture.html#afc2fe5913f8d46095f6420edc5bc7992", null ]
 ];
\ No newline at end of file
