@@ -5,8 +5,8 @@ var class_ogre_1_1_g_l3_plus_texture_buffer =
     [ "bindToFramebuffer", "class_ogre_1_1_g_l3_plus_texture_buffer.html#aa3831a22d3b707e225834e2e9237f169", null ],
     [ "upload", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a280e9b49c416c61e85607896909977c4", null ],
     [ "download", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a294c9c2d6b9ad413594948cae9d9cdbd", null ],
-    [ "blitFromMemory", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a6e79aac4862369c94144527e10a4b509", null ],
+    [ "blitFromMemory", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a954d30281ff4ac9e2b9fcd4a0852eaa6", null ],
     [ "copyFromFramebuffer", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a411f93805488efaff896ef03199b7ba8", null ],
     [ "blit", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a8971a42414b393dc9bb16b7e808a7d36", null ],
-    [ "blitFromTexture", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a9f3bf61ecc5b89e367176a5ae0d044bc", null ]
+    [ "blitToMemory", "class_ogre_1_1_g_l3_plus_texture_buffer.html#a2a47178f32af3292fa61757967ab5449", null ]
 ];
\ No newline at end of file
