@@ -2,11 +2,11 @@ var class_ogre_1_1_g_l_e_s2_texture_buffer =
 [
     [ "GLES2TextureBuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#af80d12cf417b29e367f720b1f5b3bb88", null ],
     [ "~GLES2TextureBuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a5c081823170f336161ea6b7c2190e4f5", null ],
-    [ "bindToFramebuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a872bd508d9d88262feab669d8b0b8012", null ],
+    [ "bindToFramebuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#afffec482134335945893f16f8d889923", null ],
     [ "upload", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a8bc58d877002f01258f50ca561352224", null ],
     [ "download", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a0087fbf6c5cfed59053ae33957429c4c", null ],
     [ "blitFromMemory", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a10f2bcca6c5ceefe6a545a7e6ec5b05f", null ],
     [ "copyFromFramebuffer", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a50be5ca625a1f78c4ed9c13cdef987e4", null ],
     [ "blit", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a6381723c6da01fc41a8cc8e31efeae08", null ],
-    [ "blitFromTexture", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#a33756696b7eee3471a938ab47858991a", null ]
+    [ "blitToMemory", "class_ogre_1_1_g_l_e_s2_texture_buffer.html#aef1d6de27906e85c03e00c250962e4ed", null ]
 ];
\ No newline at end of file
