@@ -4,6 +4,5 @@ var class_ogre_1_1_g_l_gpu_nvparse_program =
     [ "~GLGpuNvparseProgram", "class_ogre_1_1_g_l_gpu_nvparse_program.html#aead1cb17fd23bb7edb215c431c117e34", null ],
     [ "bindProgram", "class_ogre_1_1_g_l_gpu_nvparse_program.html#a633d598acce2253754008929c1f5a404", null ],
     [ "unbindProgram", "class_ogre_1_1_g_l_gpu_nvparse_program.html#a20def8a09cbb1e79481f9fbea291751c", null ],
-    [ "bindProgramParameters", "class_ogre_1_1_g_l_gpu_nvparse_program.html#a65e2516b1f83f99bf89606644f624871", null ],
-    [ "getProgramID", "class_ogre_1_1_g_l_gpu_nvparse_program.html#a538ce1fa9aec4dbb20b6983eb16bc426", null ]
+    [ "bindProgramParameters", "class_ogre_1_1_g_l_gpu_nvparse_program.html#a65e2516b1f83f99bf89606644f624871", null ]
 ];
\ No newline at end of file
