@@ -5,6 +5,8 @@ var class_ogre_1_1_g_l_s_l_shader =
     [ "attachToProgramObject", "class_ogre_1_1_g_l_s_l_shader.html#a4b58b5348b9c56fa600f392ef4a1730b", null ],
     [ "detachFromProgramObject", "class_ogre_1_1_g_l_s_l_shader.html#abd9602c70e3f5c681d37229b2fedcc77", null ],
     [ "linkSeparable", "class_ogre_1_1_g_l_s_l_shader.html#ab43e5c0c6223273add819bea68730a9f", null ],
+    [ "setSamplerBinding", "class_ogre_1_1_g_l_s_l_shader.html#a16feb07a3507db3b61412b73c16de64e", null ],
+    [ "getSamplerBinding", "class_ogre_1_1_g_l_s_l_shader.html#a888c2a577b9a52fe79f0befbd6171b5c", null ],
     [ "getDefaultBuffer", "class_ogre_1_1_g_l_s_l_shader.html#a9574a2cc2a185ef8208525114a5bde44", null ],
     [ "getLanguage", "class_ogre_1_1_g_l_s_l_shader.html#a5172618ce54ccd45b89769b3e8ae1d51", null ]
 ];
\ No newline at end of file
