@@ -2,12 +2,12 @@ var class_ogre_1_1_g_l_texture_buffer =
 [
     [ "GLTextureBuffer", "class_ogre_1_1_g_l_texture_buffer.html#a32dc7ed1871f4846e9a932d26821ae4f", null ],
     [ "~GLTextureBuffer", "class_ogre_1_1_g_l_texture_buffer.html#a6412531a4491a772547a79d707808708", null ],
-    [ "bindToFramebuffer", "class_ogre_1_1_g_l_texture_buffer.html#ae4ff154f1423d4e51eacab4f2df65fb2", null ],
+    [ "bindToFramebuffer", "class_ogre_1_1_g_l_texture_buffer.html#a0adce227dac1e9c8969f15ea90f179a7", null ],
     [ "getRenderTarget", "class_ogre_1_1_g_l_texture_buffer.html#a7de2db3e7c0c9ca4910025ca1e62cf65", null ],
     [ "upload", "class_ogre_1_1_g_l_texture_buffer.html#a8df0924cc51a94ab35268af565a4bdbf", null ],
     [ "download", "class_ogre_1_1_g_l_texture_buffer.html#a8fd5085b5b79dac231a0e75340b6a114", null ],
     [ "blitFromMemory", "class_ogre_1_1_g_l_texture_buffer.html#a208ce535b8b6bbbdffb196a12907ad77", null ],
     [ "copyFromFramebuffer", "class_ogre_1_1_g_l_texture_buffer.html#ae55a94d4b5d740c9f5cb26247531d6b6", null ],
     [ "blit", "class_ogre_1_1_g_l_texture_buffer.html#a98b9de8a6777122e08219785fb8e03b2", null ],
-    [ "blitFromTexture", "class_ogre_1_1_g_l_texture_buffer.html#aa69cd5e3d7ce0177f078c1d537861418", null ]
+    [ "blitToMemory", "class_ogre_1_1_g_l_texture_buffer.html#a6fbed7991a5b626cda5e7ea3db15a8e4", null ]
 ];
\ No newline at end of file
