@@ -1,6 +1,5 @@
 var group___overlays =
 [
-    [ "Ogre::OverlayElementCommands", "namespace_ogre_1_1_overlay_element_commands.html", null ],
     [ "Ogre::BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html", [
       [ "BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html#a7d44bfd5ed63179395fb90ac62e73870", null ],
       [ "~BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html#a8508eefdf3913b80de4cd99bce987583", null ],
@@ -46,8 +45,7 @@ var group___overlays =
       [ "getWorldTransforms", "class_ogre_1_1_border_renderable.html#ac63f4204d3733523975908ac00c4658a", null ],
       [ "getNumWorldTransforms", "class_ogre_1_1_border_renderable.html#a5aa0618332344aa34d1e9aa602375812", null ],
       [ "getSquaredViewDepth", "class_ogre_1_1_border_renderable.html#aa7f6b2da6115e327f9743643beb255c1", null ],
-      [ "getLights", "class_ogre_1_1_border_renderable.html#afd2b5746059b2eefff07b0c223a5ab9d", null ],
-      [ "getPolygonModeOverrideable", "class_ogre_1_1_border_renderable.html#a256b7047c3a09c43f4063b9563356781", null ]
+      [ "getLights", "class_ogre_1_1_border_renderable.html#afd2b5746059b2eefff07b0c223a5ab9d", null ]
     ] ],
     [ "Ogre::Font", "class_ogre_1_1_font.html", [
       [ "CodePoint", "class_ogre_1_1_font.html#aaaa89c1bd6898818423e9ba89502cab3", null ],
@@ -86,7 +84,6 @@ var group___overlays =
       [ "~FontManager", "class_ogre_1_1_font_manager.html#af5a0d804aaaa961248f0bc4ae92ccad5", null ],
       [ "create", "class_ogre_1_1_font_manager.html#ad75e17a4f44f40172e5b458e17d4e4bb", null ],
       [ "getByName", "class_ogre_1_1_font_manager.html#a48cb5b5c89b9e3b9b5c15f9dbf8b9256", null ],
-      [ "parseScript", "class_ogre_1_1_font_manager.html#ada6af0d588fd5c17f0f8f7904fa657a8", null ],
       [ "getSingleton", "class_ogre_1_1_font_manager.html#a7953d419aa5a23ed8c434c37065c4cc5", null ],
       [ "getSingletonPtr", "class_ogre_1_1_font_manager.html#af8c3a7f195076706aaed7707e56d5fa0", null ]
     ] ],
