@@ -4,10 +4,12 @@ var namespacemembers_eval =
     [ "a", "namespacemembers_eval_a.html", null ],
     [ "b", "namespacemembers_eval_b.html", null ],
     [ "c", "namespacemembers_eval_c.html", null ],
+    [ "e", "namespacemembers_eval_e.html", null ],
     [ "f", "namespacemembers_eval_f.html", null ],
     [ "g", "namespacemembers_eval_g.html", null ],
     [ "h", "namespacemembers_eval_h.html", null ],
     [ "i", "namespacemembers_eval_i.html", null ],
+    [ "j", "namespacemembers_eval_j.html", null ],
     [ "k", "namespacemembers_eval_k.html", null ],
     [ "l", "namespacemembers_eval_l.html", null ],
     [ "m", "namespacemembers_eval_m.html", null ],
