@@ -1,70 +1,21 @@
 var NAVTREEINDEX7 =
 {
-"class_ogre_1_1_any_numeric.html#a4876b20914b902652dbe369730adce14":[5,0,2,3,10],
-"class_ogre_1_1_any_numeric.html#a4ae6f94e660d94bad3db5baa2ea21fcf":[5,0,2,3,9],
-"class_ogre_1_1_any_numeric.html#a56d143332e5388489b3a3c3a11c45e30":[5,0,2,3,1],
-"class_ogre_1_1_any_numeric.html#a70e54709e177f5dbbeab34999e416e1c":[5,0,2,3,6],
-"class_ogre_1_1_any_numeric.html#a9ae2045cc85e7a8e134d54e0babc2a3f":[5,0,2,3,2],
-"class_ogre_1_1_any_numeric.html#aa45d67ae6ca4fca3214d1fba1630e6e5":[5,0,2,3,8],
-"class_ogre_1_1_any_numeric.html#aabe924a548e888f5f97e02f10bf307e6":[5,0,2,3,5],
-"class_ogre_1_1_any_numeric.html#ac3b74981a5214fd6b7983f7983bc4065":[5,0,2,3,11],
-"class_ogre_1_1_any_numeric.html#ad4b1c2bf0151e7ec59a67f47b749c123":[5,0,2,3,7],
-"class_ogre_1_1_any_numeric.html#ae46b3b0ebe2e956031cfa3f771087708":[5,0,2,3,0],
-"class_ogre_1_1_any_numeric.html#af32699bb01aeef60f6f3e8b92a62baf0":[5,0,2,3,12],
-"class_ogre_1_1_any_numeric.html#afb607a830f1b756959d794e05c4a6e56":[5,0,2,3,3],
-"class_ogre_1_1_archive.html":[5,0,8,1],
-"class_ogre_1_1_archive.html#a2576b8e885e59bc7c885f10a429cbf98":[5,0,8,1,12],
-"class_ogre_1_1_archive.html#a2cf28a9b3219568373208962d94af401":[5,0,8,1,13],
-"class_ogre_1_1_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[5,0,8,1,6],
-"class_ogre_1_1_archive.html#a370fba29d752fa317e992aec6625d5ed":[5,0,8,1,1],
-"class_ogre_1_1_archive.html#a40a0c629ec78d3f7b8b4f0206d9daffe":[5,0,8,1,10],
-"class_ogre_1_1_archive.html#a4169eee25281ebb54adeb9f06d9a7d80":[5,0,8,1,3],
-"class_ogre_1_1_archive.html#a5c2927f6a35441ea77262f95e4b0a6a0":[5,0,8,1,5],
-"class_ogre_1_1_archive.html#a6a073d74d1fab7d5499a35fab466c1b3":[5,0,8,1,4],
-"class_ogre_1_1_archive.html#a6f0364f262df461222f82f3baee71d70":[5,0,8,1,11],
-"class_ogre_1_1_archive.html#a764ca3926e461dc2811883f1117d9af7":[5,0,8,1,14],
-"class_ogre_1_1_archive.html#a7d03ab8a7ef32e314a5efbbf036f104e":[5,0,8,1,9],
-"class_ogre_1_1_archive.html#a919327fffdf74b7bc02bab6821732cd1":[5,0,8,1,7],
-"class_ogre_1_1_archive.html#a97f9929a9f3bafe00ede46256948ebad":[5,0,8,1,15],
-"class_ogre_1_1_archive.html#aa527675b915110919a754a226feebc4f":[5,0,8,1,0],
-"class_ogre_1_1_archive.html#ab63e6a2843a2db30eef7855616ff3440":[5,0,8,1,16],
-"class_ogre_1_1_archive.html#ac0ef7c79a59d89cdad41eaaba7b58cc5":[5,0,8,1,8],
-"class_ogre_1_1_archive.html#aee650b957194abaf771ea81b41da36fe":[5,0,8,1,2],
-"class_ogre_1_1_archive_factory.html":[5,0,8,2],
-"class_ogre_1_1_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[5,0,8,2,2],
-"class_ogre_1_1_archive_factory.html#a51a3c68688eca8878bdecdc44929ee1a":[5,0,8,2,1],
-"class_ogre_1_1_archive_factory.html#ad9799ad36b5e40eda7e755e13ec3ee06":[5,0,8,2,0],
-"class_ogre_1_1_archive_manager.html":[5,0,8,3],
-"class_ogre_1_1_archive_manager.html#a05baddedf360653448d436c33dbf0de3":[5,0,8,3,5],
-"class_ogre_1_1_archive_manager.html#a0abcd0bcbab592304b00023b87d2b48e":[5,0,8,3,2],
-"class_ogre_1_1_archive_manager.html#a4319f795e98ad1b4a200438124adea06":[5,0,8,3,9],
-"class_ogre_1_1_archive_manager.html#a4af6cf74f6bc68dfbc25032799261c3a":[5,0,8,3,1],
-"class_ogre_1_1_archive_manager.html#a4b19e2493333e34658adcfb9c5e95aa1":[5,0,8,3,8],
-"class_ogre_1_1_archive_manager.html#a912729e3f6383f3883ffd361bca0464f":[5,0,8,3,0],
-"class_ogre_1_1_archive_manager.html#ab6c255acb890a2d21ae1d3379a512730":[5,0,8,3,7],
-"class_ogre_1_1_archive_manager.html#abbd80b38555563f8c2b58956e04943cb":[5,0,8,3,6],
-"class_ogre_1_1_archive_manager.html#af73507a6125a506605a3bd7e36376ce4":[5,0,8,3,3],
-"class_ogre_1_1_archive_manager.html#afae10919b8d8d0884fe413d56a683006":[5,0,8,3,4],
-"class_ogre_1_1_area_emitter.html":[5,2,9,0],
-"class_ogre_1_1_area_emitter.html#a0675cd5508ed0a37fa6613ad5d0978c5":[5,2,9,0,12],
-"class_ogre_1_1_area_emitter.html#a123c22ed81e96c90b5cb096d11e26aae":[5,2,9,0,6],
-"class_ogre_1_1_area_emitter.html#a12c7b04420ff5aa08741d114053daff8":[5,2,9,0,10],
-"class_ogre_1_1_area_emitter.html#a22a39275e9ef9e14d9d873acda400816":[5,2,9,0,4],
-"class_ogre_1_1_area_emitter.html#a47b1c383608e0aca4859c6ecd11d9ef5":[5,2,9,0,5],
-"class_ogre_1_1_area_emitter.html#a7063e13cbae9dd5a667f2a05d48fdf43":[5,2,9,0,9],
-"class_ogre_1_1_area_emitter.html#a872608a91795338bb63962d696289eea":[5,2,9,0,8],
-"class_ogre_1_1_area_emitter.html#a8ada445a7c60d99d81304417a386f787":[5,2,9,0,7],
-"class_ogre_1_1_area_emitter.html#aa0784075820b4bdf48c687986ac77117":[5,2,9,0,11],
-"class_ogre_1_1_area_emitter.html#abd1f39890124c00dc6acce88c71e8d3b":[5,2,9,0,3],
-"class_ogre_1_1_area_emitter_1_1_cmd_depth.html":[5,2,9,0,0],
-"class_ogre_1_1_area_emitter_1_1_cmd_depth.html#a23513dcabcf5a1ba3c9b2f0dca7e59d7":[5,2,9,0,0,1],
-"class_ogre_1_1_area_emitter_1_1_cmd_depth.html#a6e51bbdf450fa280119e0ed3e5262308":[5,2,9,0,0,0],
-"class_ogre_1_1_area_emitter_1_1_cmd_height.html":[5,2,9,0,1],
-"class_ogre_1_1_area_emitter_1_1_cmd_height.html#a018b4c9a19bf91d5c37257434e8ba8b9":[5,2,9,0,1,1],
-"class_ogre_1_1_area_emitter_1_1_cmd_height.html#a211634d8f243f4c5b52ee7501f71c10b":[5,2,9,0,1,0],
-"class_ogre_1_1_area_emitter_1_1_cmd_width.html":[5,2,9,0,2],
-"class_ogre_1_1_area_emitter_1_1_cmd_width.html#a19af1cabc5d2a835e15c018c0b27159a":[5,2,9,0,2,1],
-"class_ogre_1_1_area_emitter_1_1_cmd_width.html#a67f104171efb09af068667d82798a015":[5,2,9,0,2,0],
+"class_ogre_1_1_area_emitter.html#a22a39275e9ef9e14d9d873acda400816":[5,2,10,0,4],
+"class_ogre_1_1_area_emitter.html#a47b1c383608e0aca4859c6ecd11d9ef5":[5,2,10,0,5],
+"class_ogre_1_1_area_emitter.html#a7063e13cbae9dd5a667f2a05d48fdf43":[5,2,10,0,9],
+"class_ogre_1_1_area_emitter.html#a872608a91795338bb63962d696289eea":[5,2,10,0,8],
+"class_ogre_1_1_area_emitter.html#a8ada445a7c60d99d81304417a386f787":[5,2,10,0,7],
+"class_ogre_1_1_area_emitter.html#aa0784075820b4bdf48c687986ac77117":[5,2,10,0,11],
+"class_ogre_1_1_area_emitter.html#abd1f39890124c00dc6acce88c71e8d3b":[5,2,10,0,3],
+"class_ogre_1_1_area_emitter_1_1_cmd_depth.html":[5,2,10,0,0],
+"class_ogre_1_1_area_emitter_1_1_cmd_depth.html#a23513dcabcf5a1ba3c9b2f0dca7e59d7":[5,2,10,0,0,1],
+"class_ogre_1_1_area_emitter_1_1_cmd_depth.html#a6e51bbdf450fa280119e0ed3e5262308":[5,2,10,0,0,0],
+"class_ogre_1_1_area_emitter_1_1_cmd_height.html":[5,2,10,0,1],
+"class_ogre_1_1_area_emitter_1_1_cmd_height.html#a018b4c9a19bf91d5c37257434e8ba8b9":[5,2,10,0,1,1],
+"class_ogre_1_1_area_emitter_1_1_cmd_height.html#a211634d8f243f4c5b52ee7501f71c10b":[5,2,10,0,1,0],
+"class_ogre_1_1_area_emitter_1_1_cmd_width.html":[5,2,10,0,2],
+"class_ogre_1_1_area_emitter_1_1_cmd_width.html#a19af1cabc5d2a835e15c018c0b27159a":[5,2,10,0,2,1],
+"class_ogre_1_1_area_emitter_1_1_cmd_width.html#a67f104171efb09af068667d82798a015":[5,2,10,0,2,0],
 "class_ogre_1_1_assimp_loader.html":[5,2,0,0],
 "class_ogre_1_1_assimp_loader.html#a4c2dd8325ed123d2a36a2f4e591d8214":[5,2,0,0,4],
 "class_ogre_1_1_assimp_loader.html#a51fb2bc0c2e81a42355ced11ee1bd135":[5,2,0,0,2],
@@ -249,5 +200,54 @@ var NAVTREEINDEX7 =
 "class_ogre_1_1_axis_aligned_box.html#a9abfa2f7b652f0418d6b5236cd18390e":[5,0,6,2,4],
 "class_ogre_1_1_axis_aligned_box.html#a9b836910838871e786c621e63257ef8b":[5,0,6,2,49],
 "class_ogre_1_1_axis_aligned_box.html#aa248737509768d1016c0fa36313b310c":[5,0,6,2,34],
-"class_ogre_1_1_axis_aligned_box.html#aa52a0227880a6d6487007c939de260c5":[5,0,6,2,46]
+"class_ogre_1_1_axis_aligned_box.html#aa52a0227880a6d6487007c939de260c5":[5,0,6,2,46],
+"class_ogre_1_1_axis_aligned_box.html#aa7428e161d37a9715501c678d919eb2a":[5,0,6,2,29],
+"class_ogre_1_1_axis_aligned_box.html#aaabc20c599407d00f563b8e71db6a4e5":[5,0,6,2,35],
+"class_ogre_1_1_axis_aligned_box.html#ab8f460db81d836e4b898e9f326c324d0":[5,0,6,2,19],
+"class_ogre_1_1_axis_aligned_box.html#ac30510d2cc6d94895a019eff6c9b3712":[5,0,6,2,33],
+"class_ogre_1_1_axis_aligned_box.html#ac33a45e9c52c720c900469d128be44d8":[5,0,6,2,7],
+"class_ogre_1_1_axis_aligned_box.html#ac500b5c0c4b894d031e5c53357586358":[5,0,6,2,6],
+"class_ogre_1_1_axis_aligned_box.html#ac546dc901a1f32d30b9287928c6c7c99":[5,0,6,2,0],
+"class_ogre_1_1_axis_aligned_box.html#aca408c7b88cfc2bcddde8bac8095f0ef":[5,0,6,2,39],
+"class_ogre_1_1_axis_aligned_box.html#ace4bd8141eb4f5984e52a6cb31e7a571":[5,0,6,2,11],
+"class_ogre_1_1_axis_aligned_box.html#ad1b10226c7dd82d5714f8d50c5fd4e04":[5,0,6,2,52],
+"class_ogre_1_1_axis_aligned_box.html#ad77340197d2e06137e82cbae79c895ee":[5,0,6,2,37],
+"class_ogre_1_1_axis_aligned_box.html#add7b06de5a0ba0a53ef56ec66df073d4":[5,0,6,2,31],
+"class_ogre_1_1_axis_aligned_box.html#add94e07188153b2814c5854066b1626b":[5,0,6,2,44],
+"class_ogre_1_1_axis_aligned_box.html#ae2e7a8dc14154120b288aabd468fe9d3":[5,0,6,2,27],
+"class_ogre_1_1_axis_aligned_box.html#ae3870fdd15eec672cbb31a72243b9099":[5,0,6,2,14],
+"class_ogre_1_1_axis_aligned_box.html#ae61ad12fad9545d49554ac6fcb9da224":[5,0,6,2,17],
+"class_ogre_1_1_axis_aligned_box.html#ae941f98591ec937ed8c8d4b39795db67":[5,0,6,2,24],
+"class_ogre_1_1_axis_aligned_box.html#aebb44ed507a75cdfbc4bc0fff365ffc7":[5,0,6,2,12],
+"class_ogre_1_1_axis_aligned_box.html#aeeaf7fff274080e2c941fc994d7510ed":[5,0,6,2,47],
+"class_ogre_1_1_axis_aligned_box.html#aefda8f8b625a288d833730d4b2feb099":[5,0,6,2,28],
+"class_ogre_1_1_axis_aligned_box.html#af3ad8fdc676dc194817f6b7699914d5d":[5,0,6,2,26],
+"class_ogre_1_1_axis_aligned_box.html#af7b08b182001076152493c08aab0f162":[5,0,6,2,42],
+"class_ogre_1_1_axis_aligned_box_scene_query.html":[5,0,9,0],
+"class_ogre_1_1_axis_aligned_box_scene_query.html#a38a312d421dd3c635490a5bae7397b87":[5,0,9,0,1],
+"class_ogre_1_1_axis_aligned_box_scene_query.html#a94a8b80423e82f9ddcbf4a3f149270ad":[5,0,9,0,3],
+"class_ogre_1_1_axis_aligned_box_scene_query.html#ac9f17a2607f960bc1ce451522994960c":[5,0,9,0,2],
+"class_ogre_1_1_axis_aligned_box_scene_query.html#ae61b5e8ce50437c582e078bc327b7473":[5,0,9,0,0],
+"class_ogre_1_1_base_instance_batch_v_t_f.html":[5,0,9,1],
+"class_ogre_1_1_billboard.html":[5,0,1,0],
+"class_ogre_1_1_billboard.html#a0e78e6b90bbf3184f45d0a87bbeb229b":[5,0,1,0,6],
+"class_ogre_1_1_billboard.html#a22f28d979395f04c6039d46a68c4eefb":[5,0,1,0,18],
+"class_ogre_1_1_billboard.html#a261647d2b3ed936e9a2f05309ae878d0":[5,0,1,0,22],
+"class_ogre_1_1_billboard.html#a39ef001d2052cbae98014753e210b732":[5,0,1,0,0],
+"class_ogre_1_1_billboard.html#a3aced837be58b2b578c5cc63b87e01c3":[5,0,1,0,15],
+"class_ogre_1_1_billboard.html#a3ef9bffd0c2a51d1bbac274bdf86c869":[5,0,1,0,1],
+"class_ogre_1_1_billboard.html#a5b2103881f1525ba045ee8d8e9a2b1b0":[5,0,1,0,13],
+"class_ogre_1_1_billboard.html#a64425b354973d2d957bc878fca407aad":[5,0,1,0,24],
+"class_ogre_1_1_billboard.html#a67c55fa7b1487eece36c78bc0148e843":[5,0,1,0,17],
+"class_ogre_1_1_billboard.html#a7cb91052db2dd96a2c5c09d404f749a8":[5,0,1,0,3],
+"class_ogre_1_1_billboard.html#a7f055c0ed81c6b3bef6d154d128093a1":[5,0,1,0,21],
+"class_ogre_1_1_billboard.html#a84d6153b0b9a5f86af082129e6ba0440":[5,0,1,0,19],
+"class_ogre_1_1_billboard.html#a8e64eda09ec65dea10dc180b68801d94":[5,0,1,0,4],
+"class_ogre_1_1_billboard.html#a9126c29605e55b8bdb5f81adf267259a":[5,0,1,0,10],
+"class_ogre_1_1_billboard.html#a93b6333aff2ef4c3bcf2c426d44dcef1":[5,0,1,0,8],
+"class_ogre_1_1_billboard.html#aa55e75efab0444062dce5b2bbd934acd":[5,0,1,0,14],
+"class_ogre_1_1_billboard.html#aa7ad6c8789d8589787c4da34c670d66c":[5,0,1,0,23],
+"class_ogre_1_1_billboard.html#ab492f811d69f1e4e3cae03150f32da90":[5,0,1,0,20],
+"class_ogre_1_1_billboard.html#ab960e05a2be7d41bbf573932f6075465":[5,0,1,0,11],
+"class_ogre_1_1_billboard.html#ad861053413ca65e059dd74131a084839":[5,0,1,0,26]
 };
