@@ -1,54 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"class_ogre_1_1_axis_aligned_box.html#aa7428e161d37a9715501c678d919eb2a":[5,0,6,2,29],
-"class_ogre_1_1_axis_aligned_box.html#aaabc20c599407d00f563b8e71db6a4e5":[5,0,6,2,35],
-"class_ogre_1_1_axis_aligned_box.html#ab8f460db81d836e4b898e9f326c324d0":[5,0,6,2,19],
-"class_ogre_1_1_axis_aligned_box.html#ac30510d2cc6d94895a019eff6c9b3712":[5,0,6,2,33],
-"class_ogre_1_1_axis_aligned_box.html#ac33a45e9c52c720c900469d128be44d8":[5,0,6,2,7],
-"class_ogre_1_1_axis_aligned_box.html#ac500b5c0c4b894d031e5c53357586358":[5,0,6,2,6],
-"class_ogre_1_1_axis_aligned_box.html#ac546dc901a1f32d30b9287928c6c7c99":[5,0,6,2,0],
-"class_ogre_1_1_axis_aligned_box.html#aca408c7b88cfc2bcddde8bac8095f0ef":[5,0,6,2,39],
-"class_ogre_1_1_axis_aligned_box.html#ace4bd8141eb4f5984e52a6cb31e7a571":[5,0,6,2,11],
-"class_ogre_1_1_axis_aligned_box.html#ad1b10226c7dd82d5714f8d50c5fd4e04":[5,0,6,2,52],
-"class_ogre_1_1_axis_aligned_box.html#ad77340197d2e06137e82cbae79c895ee":[5,0,6,2,37],
-"class_ogre_1_1_axis_aligned_box.html#add7b06de5a0ba0a53ef56ec66df073d4":[5,0,6,2,31],
-"class_ogre_1_1_axis_aligned_box.html#add94e07188153b2814c5854066b1626b":[5,0,6,2,44],
-"class_ogre_1_1_axis_aligned_box.html#ae2e7a8dc14154120b288aabd468fe9d3":[5,0,6,2,27],
-"class_ogre_1_1_axis_aligned_box.html#ae3870fdd15eec672cbb31a72243b9099":[5,0,6,2,14],
-"class_ogre_1_1_axis_aligned_box.html#ae61ad12fad9545d49554ac6fcb9da224":[5,0,6,2,17],
-"class_ogre_1_1_axis_aligned_box.html#ae941f98591ec937ed8c8d4b39795db67":[5,0,6,2,24],
-"class_ogre_1_1_axis_aligned_box.html#aebb44ed507a75cdfbc4bc0fff365ffc7":[5,0,6,2,12],
-"class_ogre_1_1_axis_aligned_box.html#aeeaf7fff274080e2c941fc994d7510ed":[5,0,6,2,47],
-"class_ogre_1_1_axis_aligned_box.html#aefda8f8b625a288d833730d4b2feb099":[5,0,6,2,28],
-"class_ogre_1_1_axis_aligned_box.html#af3ad8fdc676dc194817f6b7699914d5d":[5,0,6,2,26],
-"class_ogre_1_1_axis_aligned_box.html#af7b08b182001076152493c08aab0f162":[5,0,6,2,42],
-"class_ogre_1_1_axis_aligned_box_scene_query.html":[5,0,9,0],
-"class_ogre_1_1_axis_aligned_box_scene_query.html#a38a312d421dd3c635490a5bae7397b87":[5,0,9,0,1],
-"class_ogre_1_1_axis_aligned_box_scene_query.html#a94a8b80423e82f9ddcbf4a3f149270ad":[5,0,9,0,3],
-"class_ogre_1_1_axis_aligned_box_scene_query.html#ac9f17a2607f960bc1ce451522994960c":[5,0,9,0,2],
-"class_ogre_1_1_axis_aligned_box_scene_query.html#ae61b5e8ce50437c582e078bc327b7473":[5,0,9,0,0],
-"class_ogre_1_1_base_instance_batch_v_t_f.html":[5,0,9,1],
-"class_ogre_1_1_billboard.html":[5,0,1,0],
-"class_ogre_1_1_billboard.html#a0e78e6b90bbf3184f45d0a87bbeb229b":[5,0,1,0,6],
-"class_ogre_1_1_billboard.html#a22f28d979395f04c6039d46a68c4eefb":[5,0,1,0,18],
-"class_ogre_1_1_billboard.html#a261647d2b3ed936e9a2f05309ae878d0":[5,0,1,0,22],
-"class_ogre_1_1_billboard.html#a39ef001d2052cbae98014753e210b732":[5,0,1,0,0],
-"class_ogre_1_1_billboard.html#a3aced837be58b2b578c5cc63b87e01c3":[5,0,1,0,15],
-"class_ogre_1_1_billboard.html#a3ef9bffd0c2a51d1bbac274bdf86c869":[5,0,1,0,1],
-"class_ogre_1_1_billboard.html#a5b2103881f1525ba045ee8d8e9a2b1b0":[5,0,1,0,13],
-"class_ogre_1_1_billboard.html#a64425b354973d2d957bc878fca407aad":[5,0,1,0,24],
-"class_ogre_1_1_billboard.html#a67c55fa7b1487eece36c78bc0148e843":[5,0,1,0,17],
-"class_ogre_1_1_billboard.html#a7cb91052db2dd96a2c5c09d404f749a8":[5,0,1,0,3],
-"class_ogre_1_1_billboard.html#a7f055c0ed81c6b3bef6d154d128093a1":[5,0,1,0,21],
-"class_ogre_1_1_billboard.html#a84d6153b0b9a5f86af082129e6ba0440":[5,0,1,0,19],
-"class_ogre_1_1_billboard.html#a8e64eda09ec65dea10dc180b68801d94":[5,0,1,0,4],
-"class_ogre_1_1_billboard.html#a9126c29605e55b8bdb5f81adf267259a":[5,0,1,0,10],
-"class_ogre_1_1_billboard.html#a93b6333aff2ef4c3bcf2c426d44dcef1":[5,0,1,0,8],
-"class_ogre_1_1_billboard.html#aa55e75efab0444062dce5b2bbd934acd":[5,0,1,0,14],
-"class_ogre_1_1_billboard.html#aa7ad6c8789d8589787c4da34c670d66c":[5,0,1,0,23],
-"class_ogre_1_1_billboard.html#ab492f811d69f1e4e3cae03150f32da90":[5,0,1,0,20],
-"class_ogre_1_1_billboard.html#ab960e05a2be7d41bbf573932f6075465":[5,0,1,0,11],
-"class_ogre_1_1_billboard.html#ad861053413ca65e059dd74131a084839":[5,0,1,0,26],
 "class_ogre_1_1_billboard.html#ae05d9ca75a8fa8b6f2a0fe0c0fa8c748":[5,0,1,0,7],
 "class_ogre_1_1_billboard.html#ae5bf31f1d013a1f0c3b5a92e46c76d11":[5,0,1,0,9],
 "class_ogre_1_1_billboard.html#ae8aa54c0303721dfc34ebbd8bdf1e8f4":[5,0,1,0,16],
@@ -99,13 +50,13 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_billboard_chain.html#afbfba68f0e99d3bac382b3c7b53e571c":[5,0,1,1,28],
 "class_ogre_1_1_billboard_chain.html#afe208f1c230dc69b02e118417892f122":[5,0,1,1,22],
 "class_ogre_1_1_billboard_chain_1_1_element.html":[5,0,1,1,0],
-"class_ogre_1_1_billboard_chain_1_1_element.html#a12ba93bd71664de7567e0f8e84cd3691":[5,0,1,1,0,3],
 "class_ogre_1_1_billboard_chain_1_1_element.html#a511a534a85e4accfbbdcb34dc4bcd66c":[5,0,1,1,0,6],
 "class_ogre_1_1_billboard_chain_1_1_element.html#a68874dd0bbc8cae9ac036dfc45aeec4b":[5,0,1,1,0,0],
-"class_ogre_1_1_billboard_chain_1_1_element.html#a8002c580266cf64b506d2558f86f0146":[5,0,1,1,0,1],
+"class_ogre_1_1_billboard_chain_1_1_element.html#a77798f9eb4a49fc6b9f1c1e090fb7390":[5,0,1,1,0,1],
 "class_ogre_1_1_billboard_chain_1_1_element.html#a8ba26812cafc456d1ffcdafba1edc4c7":[5,0,1,1,0,2],
 "class_ogre_1_1_billboard_chain_1_1_element.html#aca293130c8752d30fc6a7bee3252fc36":[5,0,1,1,0,5],
-"class_ogre_1_1_billboard_chain_1_1_element.html#adfcbe79d8b6bd60c8ea91c2c75f92f46":[5,0,1,1,0,4],
+"class_ogre_1_1_billboard_chain_1_1_element.html#ad8e03d7b5242ed921f24ff30c7d7dcf7":[5,0,1,1,0,4],
+"class_ogre_1_1_billboard_chain_1_1_element.html#af9d7a5e7483159c9c5469ed9e9b433f2":[5,0,1,1,0,3],
 "class_ogre_1_1_billboard_chain_factory.html":[5,0,1,2],
 "class_ogre_1_1_billboard_chain_factory.html#a2658ad034ae75ff78a19933bd2df89af":[5,0,1,2,3],
 "class_ogre_1_1_billboard_chain_factory.html#a2f92927f587d26d146244f0e4d79afc9":[5,0,1,2,0],
@@ -249,5 +200,54 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_bone.html#a5689b25eee3b487fd5e98b3c6161180a":[5,0,0,9,6],
 "class_ogre_1_1_bone.html#a5b32f720032133ebc0706669b20ee528":[5,0,0,9,13],
 "class_ogre_1_1_bone.html#a5f4ee6d5dbb21e731ab423dad2f39238":[5,0,0,9,0],
-"class_ogre_1_1_bone.html#a671b15acf329f234669f09c0406999fa":[5,0,0,9,5]
+"class_ogre_1_1_bone.html#a671b15acf329f234669f09c0406999fa":[5,0,0,9,5],
+"class_ogre_1_1_bone.html#a6e6ffb756d2ad554dcac0af5a0192054":[5,0,0,9,11],
+"class_ogre_1_1_bone.html#a728ef3b318e7133ed8a7bef3839df02b":[5,0,0,9,12],
+"class_ogre_1_1_bone.html#a991f10fa167400fb4c3f2d788b37ddd9":[5,0,0,9,3],
+"class_ogre_1_1_bone.html#a9ed63d0df8ecf6643f7b280e79b61484":[5,0,0,9,4],
+"class_ogre_1_1_bone.html#abd5f3c7b238834306cc80522c72ed00e":[5,0,0,9,10],
+"class_ogre_1_1_bone.html#ac9ece9866c1d7283825ca0fb00763422":[5,0,0,9,9],
+"class_ogre_1_1_bone.html#aeec02693c1991969ce34581e42762d40":[5,0,0,9,1],
+"class_ogre_1_1_bone.html#af0978992600bc892a062096dd9e805c8":[5,0,0,9,7],
+"class_ogre_1_1_border_panel_overlay_element.html":[5,1,3,0],
+"class_ogre_1_1_border_panel_overlay_element.html#a00b0ec54310848d495c630b7a010d748":[5,1,3,0,26],
+"class_ogre_1_1_border_panel_overlay_element.html#a0951728a2782426b57bc346141a532dd":[5,1,3,0,3],
+"class_ogre_1_1_border_panel_overlay_element.html#a0caeaa1d1379dec4133849d2c91e258e":[5,1,3,0,16],
+"class_ogre_1_1_border_panel_overlay_element.html#a1abfd6cb3ac45d219cab0c842045c06a":[5,1,3,0,22],
+"class_ogre_1_1_border_panel_overlay_element.html#a1cb930e3203523e799bab77cc484f589":[5,1,3,0,17],
+"class_ogre_1_1_border_panel_overlay_element.html#a3477f4afc62d5bbd5f73017c210ac20a":[5,1,3,0,12],
+"class_ogre_1_1_border_panel_overlay_element.html#a34cbfdb610c9f91d01c1b4adff0844ab":[5,1,3,0,35],
+"class_ogre_1_1_border_panel_overlay_element.html#a34f87bb5dee0eeaddefa30c7251e9dd7":[5,1,3,0,4],
+"class_ogre_1_1_border_panel_overlay_element.html#a3a2f7d12ffbb36c00ab3eaef1b1b3c65":[5,1,3,0,5],
+"class_ogre_1_1_border_panel_overlay_element.html#a3e872edbeda111745671ff23e982cf50":[5,1,3,0,32],
+"class_ogre_1_1_border_panel_overlay_element.html#a54f9496555af63e3370a994a4404c1a1":[5,1,3,0,13],
+"class_ogre_1_1_border_panel_overlay_element.html#a5a07d180634f96bd78e93f971cc0b8ae":[5,1,3,0,2],
+"class_ogre_1_1_border_panel_overlay_element.html#a5c0cf38bdc01f45b238a2e6ce0d8117d":[5,1,3,0,33],
+"class_ogre_1_1_border_panel_overlay_element.html#a61c0227c271d8d263225d141dbf8fcdd":[5,1,3,0,23],
+"class_ogre_1_1_border_panel_overlay_element.html#a672f841a77af2aba6bfdd5a7b7775ef3":[5,1,3,0,14],
+"class_ogre_1_1_border_panel_overlay_element.html#a695b0d43274bccc1bdb6d99d75c96b50":[5,1,3,0,6],
+"class_ogre_1_1_border_panel_overlay_element.html#a6fc22281774852483db4f1a4f20fd279":[5,1,3,0,20],
+"class_ogre_1_1_border_panel_overlay_element.html#a7d44bfd5ed63179395fb90ac62e73870":[5,1,3,0,0],
+"class_ogre_1_1_border_panel_overlay_element.html#a7f353279eeebc74cb43cae1d1b6ef344":[5,1,3,0,10],
+"class_ogre_1_1_border_panel_overlay_element.html#a8508eefdf3913b80de4cd99bce987583":[5,1,3,0,1],
+"class_ogre_1_1_border_panel_overlay_element.html#a86c397a83bbad466e552a4c6c7f36d02":[5,1,3,0,24],
+"class_ogre_1_1_border_panel_overlay_element.html#a99f805d644deeba4626100020eb1b141":[5,1,3,0,34],
+"class_ogre_1_1_border_panel_overlay_element.html#a9e2803be1666c04fe2447b97586ef891":[5,1,3,0,29],
+"class_ogre_1_1_border_panel_overlay_element.html#ab6db214eaba51905f6229229b4769c2b":[5,1,3,0,21],
+"class_ogre_1_1_border_panel_overlay_element.html#ab8e424c05e8311fe6ea5a4134fc8ea45":[5,1,3,0,31],
+"class_ogre_1_1_border_panel_overlay_element.html#ab9b5d5d6d9d243d1ab16d0e67bf852cb":[5,1,3,0,15],
+"class_ogre_1_1_border_panel_overlay_element.html#abcbfe3bb9647ffef0d6f60c76bcacecd":[5,1,3,0,9],
+"class_ogre_1_1_border_panel_overlay_element.html#ac35895cec71bd39e65c689ac2cea2ddc":[5,1,3,0,7],
+"class_ogre_1_1_border_panel_overlay_element.html#acc97506b185eead9023153c1d30a5526":[5,1,3,0,18],
+"class_ogre_1_1_border_panel_overlay_element.html#ad54e4d97854db5240b975cf8fed0095b":[5,1,3,0,19],
+"class_ogre_1_1_border_panel_overlay_element.html#ad575439d610670909df306142f1e7119":[5,1,3,0,25],
+"class_ogre_1_1_border_panel_overlay_element.html#add65c1e4bb978ed2bb8439e6b7d24e69":[5,1,3,0,8],
+"class_ogre_1_1_border_panel_overlay_element.html#adddbb68811e8b8a63859e96621adcd66":[5,1,3,0,11],
+"class_ogre_1_1_border_panel_overlay_element.html#adea6e2ab48aaeb939e8d531addd16d48":[5,1,3,0,27],
+"class_ogre_1_1_border_panel_overlay_element.html#ae2b8f950b0cdfce3dfe71d780612da16":[5,1,3,0,30],
+"class_ogre_1_1_border_panel_overlay_element.html#ae8c268cd2a81b881542959121c2ad838":[5,1,3,0,28],
+"class_ogre_1_1_border_renderable.html":[5,1,3,1],
+"class_ogre_1_1_border_renderable.html#a5aa0618332344aa34d1e9aa602375812":[5,1,3,1,4],
+"class_ogre_1_1_border_renderable.html#a70ce2657189a442f5a5b550ef532551c":[5,1,3,1,0],
+"class_ogre_1_1_border_renderable.html#a9ff04df29e386a202416853ccd45e401":[5,1,3,1,1]
 };
