@@ -7,5 +7,7 @@ var struct_ogre_bites_1_1_im_gui_input_listener =
     [ "mouseWheelRolled", "struct_ogre_bites_1_1_im_gui_input_listener.html#acba21daf003a4ae215157ecb4067f215", null ],
     [ "mousePressed", "struct_ogre_bites_1_1_im_gui_input_listener.html#a0c59ca0f974d976ac5d7abb8a351fe39", null ],
     [ "mouseReleased", "struct_ogre_bites_1_1_im_gui_input_listener.html#a495afd3499e53db6d3bd2574f90ee55d", null ],
-    [ "textInput", "struct_ogre_bites_1_1_im_gui_input_listener.html#ad1ae196500b90795620dd0634c7647bc", null ]
+    [ "textInput", "struct_ogre_bites_1_1_im_gui_input_listener.html#ad1ae196500b90795620dd0634c7647bc", null ],
+    [ "buttonPressed", "struct_ogre_bites_1_1_im_gui_input_listener.html#a3b8537b21a078a6ec1e0a823091fe1cb", null ],
+    [ "buttonReleased", "struct_ogre_bites_1_1_im_gui_input_listener.html#a66e12556fde666ecc1f6474f3f2449e4", null ]
 ];
\ No newline at end of file
